@@ -198,6 +198,71 @@ def extract_target_frame_from_timestamp(video_filepath, timestamp):
     return image
 
 
+def calc_frame_to_second_coefficient(duration, n_frame, sampling_sec=None):
+    """Calculate Frame to Second coefficient.
+
+    Parameters
+    ----------
+    duration : float
+        video duration
+    n_frame : int
+        number of frame
+    sampling_sec : float
+        time of sampling seconds
+
+    Returns
+    -------
+    frame_to_second : float
+        calculated frame to second coefficient.
+
+    Examples
+    --------
+    >>> calc_frame_to_second_coefficient(30, 60, sampling_sec=0.1)
+    0.5
+    >>> calc_frame_to_second_coefficient(30, 60, sampling_sec=0.1) * 3
+    1.5
+    """
+    duration = float(duration)
+    n_frame = float(n_frame)
+    fps = n_frame / duration
+    if sampling_sec is not None:
+        return duration * math.ceil(fps * sampling_sec) / n_frame
+    else:
+        return duration / n_frame
+
+
+def calc_second_to_frame_coefficient(duration, n_frame, sampling_sec=None):
+    """Calculate Second to Frame coefficient.
+
+    This is inverse of calc_frame_to_second_coefficient.
+
+    Parameters
+    ----------
+    duration : float
+        video duration
+    n_frame : int
+        number of frame
+    sampling_sec : float
+        time of sampling seconds
+
+    Returns
+    -------
+    second_to_frame : float
+        calculated second to frame coefficient.
+
+    Examples
+    --------
+    >>> calc_second_to_frame_coefficient(30, 60, sampling_sec=0.1)
+    2.0
+    >>> int(1.99 * calc_second_to_frame_coefficient(4, 4))
+    1
+    >>> int(1.99 * calc_second_to_frame_coefficient(4, 4, sampling_sec=2.0))
+    0
+    """
+    return 1.0 / calc_frame_to_second_coefficient(
+        duration, n_frame, sampling_sec)
+
+
 def load_frame(video_path, start=0.0, duration=-1,
                target_size=None, sampling_frequency=None):
     """Load frame
